@@ -8,9 +8,9 @@ use Net::SSLLabs::Info();
 use Net::SSLLabs::Host();
 use Net::SSLLabs::Endpoint();
 use Net::SSLLabs::StatusCodes();
-use Encode();
+use URI::Escape();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub new {
     my ($class) = @_;
@@ -37,13 +37,13 @@ sub info {
 
 sub analyze {
     my ( $self, %params ) = @_;
-    my $url =
-        $self->{url}
-      . 'analyze?'
-      . (
+    my $url = $self->{url} . 'analyze?' . (
         join q[&],
-        map { _encode($_) . q[=] . _encode( $params{$_} ) } keys %params
-      );
+        map {
+                URI::Escape::uri_escape_utf8($_) . q[=]
+              . URI::Escape::uri_escape_utf8( $params{$_} )
+        } keys %params
+    );
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
         my $host = Net::SSLLabs::Host->new(
@@ -58,15 +58,15 @@ sub analyze {
     return;
 }
 
-sub getEndpointData {
+sub get_endpoint_data {
     my ( $self, %params ) = @_;
-    my $url =
-        $self->{url}
-      . 'getEndpointData?'
-      . (
+    my $url = $self->{url} . 'getEndpointData?' . (
         join q[&],
-        map { _encode($_) . q[=] . _encode( $params{$_} ) } keys %params
-      );
+        map {
+                URI::Escape::uri_escape_utf8($_) . q[=]
+              . URI::Escape::uri_escape_utf8( $params{$_} )
+        } keys %params
+    );
     my $response = $self->{ua}->get($url);
     if ( $response->is_success() ) {
         return Net::SSLLabs::Endpoint->new(
@@ -77,7 +77,7 @@ sub getEndpointData {
     }
 }
 
-sub getStatusCodes {
+sub get_status_codes {
     my ($self)   = @_;
     my $url      = $self->{url} . 'getStatusCodes';
     my $response = $self->{ua}->get($url);
@@ -90,14 +90,6 @@ sub getStatusCodes {
     }
 }
 
-sub _encode {
-    my ($decoded) = @_;
-    my $encoded = Encode::encode( 'UTF-8', $decoded, 1 );
-    $encoded =~
-      s/([^[:alnum:]])/join('', map { uc("\%$_") } unpack("H*", $1))/semgx;
-    return $encoded;
-}
-
 1;    # End of Net::SSLLabs
 __END__
 
@@ -107,7 +99,7 @@ Net::SSLLabs - An interface to the ssllabs.com service
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -121,7 +113,7 @@ Check the security of your TLS services
         sleep 10;
     }
     foreach my $endpoint ($host->endpoints()) {
-        say $host->host() . ' at ' . $endpoint->ipAddress() . ' gets a ' . $endpoint->grade();
+        say $host->host() . ' at ' . $endpoint->ip_address() . ' gets a ' . $endpoint->grade();
     }
 
 =head1 DESCRIPTION
@@ -132,7 +124,7 @@ Net::SSLLabs provides a full interface to the API provided by ssllabs.com.
 
 =head2 new
 
-a new I<Net::SSLLabs> object, ready to process TLS services
+a new C<Net::SSLLabs> object, ready to process TLS services
 
 =head2 info
 
@@ -162,7 +154,7 @@ Parameters:
 
 =back 
 
-=head2 getEndpointData
+=head2 get_endpoint_data
 
 This call is used to retrieve detailed endpoint information. It will return a single L<Net::SSLLabs::Endpoint|Net::SSLLabs::Endpoint> object on success. The object will contain complete assessment information. This call does not initiate new assessments, even when a cached report is not found.
 
@@ -178,7 +170,7 @@ Parameters:
 
 =back 
 
-=head2 getStatusCodes
+=head2 get_status_codes
 
 This call will return one L<Net::SSLLabs::StatusCodes|Net::SSLLabs::StatusCodes> instance.
 
@@ -227,7 +219,7 @@ L<http://search.cpan.org/dist/Net-SSLLabs/>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to Ivan Ristic and the team at qualys.com for providing the service at ssllabs.com
+Thanks to Ivan Ristic and the team at L<https://www.qualys.com> for providing the service at L<https://www.ssllabs.com>
 
 POD was extracted from the API help at L<https://github.com/ssllabs/ssllabs-scan/blob/stable/ssllabs-api-docs.md>
 
