@@ -11,12 +11,12 @@ sub new {
     return $self;
 }
 
-sub altNames {
+sub alt_names {
     my ($self) = @_;
     return @{ $self->{altNames} };
 }
 
-sub issuerSubject {
+sub issuer_subject {
     my ($self) = @_;
     return $self->{issuerSubject};
 }
@@ -26,17 +26,17 @@ sub issues {
     return $self->{issues};
 }
 
-sub ocspRevocationStatus {
+sub ocsp_revocation_status {
     my ($self) = @_;
     return $self->{ocspRevocationStatus};
 }
 
-sub ocspURIs {
+sub ocsp_uris {
     my ($self) = @_;
     return map { URI->new($_) } @{ $self->{ocspURIs} };
 }
 
-sub revocationInfo {
+sub revocation_info {
     my ($self) = @_;
     return $self->{revocationInfo};
 }
@@ -46,7 +46,7 @@ sub sgc {
     return $self->{sgc} ? 1 : 0;
 }
 
-sub validationType {
+sub validation_type {
     my ($self) = @_;
     return $self->{validationType};
 }
@@ -56,22 +56,22 @@ sub sct {
     return $self->{sct} ? 1 : 0;
 }
 
-sub sigAlg {
+sub sig_alg {
     my ($self) = @_;
     return $self->{sigAlg};
 }
 
-sub commonNames {
+sub common_names {
     my ($self) = @_;
     return map { URI->new($_) } @{ $self->{commonNames} };
 }
 
-sub crlURIs {
+sub crl_uris {
     my ($self) = @_;
     return map { URI->new($_) } @{ $self->{crlURIs} };
 }
 
-sub issuerLabel {
+sub issuer_label {
     my ($self) = @_;
     return $self->{issuerLabel};
 }
@@ -81,22 +81,22 @@ sub subject {
     return $self->{subject};
 }
 
-sub notBefore {
+sub not_before {
     my ($self) = @_;
     return $self->{notBefore};
 }
 
-sub revocationStatus {
+sub revocation_status {
     my ($self) = @_;
     return $self->{revocationStatus};
 }
 
-sub notAfter {
+sub not_after {
     my ($self) = @_;
     return $self->{notAfter};
 }
 
-sub crlRevocationStatus {
+sub crl_revocation_status {
     my ($self) = @_;
     return $self->{crlRevocationStatus};
 }
@@ -112,41 +112,41 @@ Net::SSLLabs::Cert - Cert object
 
 =head2 new
 
-a new I<Net::SSLLabs::Cert> object, accepts a JSON object as it's parameter
+a new C<Net::SSLLabs::Cert> object, accepts a JSON object as it's parameter.
 
 =head2 subject
 
 certificate subject
 
-=head2 commonNames
+=head2 common_names
 
 list of common names extracted from the subject
 
-=head2 altNames
+=head2 alt_names
 
 alternative names
 
-=head2 notBefore
+=head2 not_before
 
 UNIX timestamp before which the certificate is not valid
 
-=head2 notAfter
+=head2 not_after
 
 UNIX timestamp after which the certificate is not valid
 
-=head2 issuerSubject
+=head2 issuer_subject
 
 issuer subject
 
-=head2 sigAlg
+=head2 sig_alg
 
 certificate signature algorithm
 
-=head2 issuerLabel
+=head2 issuer_label
 
 issuer name
 
-=head2 revocationInfo
+=head2 revocation_info
 
 a number that represents revocation information present in the certificate:
 
@@ -158,15 +158,15 @@ a number that represents revocation information present in the certificate:
 
 =back
 
-=head2 crlURIs
+=head2 crl_uris
 
 list of CRL L<URI|URI>s extracted from the certificate.
 
-=head2 ocspURIs
+=head2 ocsp_uris
 
 list of OCSP L<URI|URI>s extracted from the certificate
 
-=head2 revocationStatus
+=head2 revocation_status
 
 a number that describes the revocation status of the certificate:
 
@@ -186,11 +186,11 @@ a number that describes the revocation status of the certificate:
 
 =back
 
-=head2 crlRevocationStatus
+=head2 crl_revocation_status
 
 same as revocationStatus, but only for the CRL information (if any).
 
-=head2 ocspRevocationStatus
+=head2 ocsp_revocation_status
 
 same as revocationStatus, but only for the OCSP information (if any).
 
@@ -206,7 +206,7 @@ Server Gated Cryptography support; integer:
 
 =back
 
-=head2 validationType
+=head2 validation_type
 
 E for Extended Validation certificates; may be null if unable to determine
 
