@@ -20,27 +20,27 @@ sub label {
     return $self->{label};
 }
 
-sub notBefore {
+sub not_before {
     my ($self) = @_;
     return $self->{notBefore};
 }
 
-sub notAfter {
+sub not_after {
     my ($self) = @_;
     return $self->{notAfter};
 }
 
-sub issuerSubject {
+sub issuer_subject {
     my ($self) = @_;
     return $self->{issuerSubject};
 }
 
-sub issuerLabel {
+sub issuer_label {
     my ($self) = @_;
     return $self->{issuerLabel};
 }
 
-sub sigAlg {
+sub sig_alg {
     my ($self) = @_;
     return $self->{sigAlg};
 }
@@ -50,32 +50,32 @@ sub issues {
     return $self->{issues};
 }
 
-sub keyAlg {
+sub key_alg {
     my ($self) = @_;
     return $self->{keyAlg};
 }
 
-sub keySize {
+sub key_size {
     my ($self) = @_;
     return $self->{keySize};
 }
 
-sub keyStrength {
+sub key_strength {
     my ($self) = @_;
     return $self->{keyStrength};
 }
 
-sub revocationStatus {
+sub revocation_status {
     my ($self) = @_;
     return $self->{revocationStatus};
 }
 
-sub crlRevocationStatus {
+sub crl_revocation_status {
     my ($self) = @_;
     return $self->{crlRevocationStatus};
 }
 
-sub ocspRevocationStatus {
+sub ocsp_revocation_status {
     my ($self) = @_;
     return $self->{ocspRevocationStatus};
 }
@@ -96,7 +96,7 @@ Net::SSLLabs::ChainCert - ChainCert object
 
 =head2 new
 
-a new I<Net::SSLLabs::ChainCert> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::ChainCert> object, accepts a JSON object as it's parameter.
 
 =head2 subject
 
@@ -106,19 +106,19 @@ certificate subject
 
 certificate label (user-friendly name)
 
-=head2 notBefore
+=head2 not_before
 
-=head2 notAfter
+=head2 not_after
 
-=head2 issuerSubject
+=head2 issuer_subject
 
 issuer subject
 
-=head2 issuerLabel
+=head2 issuer_label
 
 issuer label (user-friendly name)
 
-=head2 sigAlg
+=head2 sig_alg
 
 =head2 issues
 
@@ -138,19 +138,19 @@ a number of flags the describe the problems with this certificate:
 
 =back
 
-=head2 keyAlg
+=head2 key_alg
 
 key algorithm.
 
-=head2 keySize
+=head2 key_size
 
 key size, in bits appopriate for the key algorithm.
 
-=head2 keyStrength
+=head2 key_strength
 
 key strength, in equivalent RSA bits.
 
-=head2 revocationStatus
+=head2 revocation_status
 
 a number that describes the revocation status of the certificate:
 
@@ -170,11 +170,11 @@ a number that describes the revocation status of the certificate:
 
 =back
 
-=head2 crlRevocationStatus
+=head2 crl_revocation_status
 
 same as revocationStatus, but only for the CRL information (if any).
 
-=head2 ocspRevocationStatus
+=head2 ocsp_revocation_status
 
 same as revocationStatus, but only for the OCSP information (if any).
 
