@@ -15,12 +15,12 @@ sub new {
     return $self;
 }
 
-sub ipAddress {
+sub ip_address {
     my ($self) = @_;
     return $self->{ipAddress};
 }
 
-sub isExceptional {
+sub is_exceptional {
     my ($self) = @_;
     return $self->{isExceptional} ? 1 : 0;
 }
@@ -30,17 +30,17 @@ sub delegation {
     return $self->{delegation};
 }
 
-sub hasWarnings {
+sub has_warnings {
     my ($self) = @_;
     return $self->{hasWarnings} ? 1 : 0;
 }
 
-sub gradeTrustIgnored {
+sub grade_trust_ignored {
     my ($self) = @_;
     return $self->{gradeTrustIgnored};
 }
 
-sub statusMessage {
+sub status_message {
     my ($self) = @_;
     return $self->{statusMessage};
 }
@@ -65,7 +65,7 @@ sub progress {
     return $self->{progress};
 }
 
-sub serverName {
+sub server_name {
     my ($self) = @_;
     return $self->{serverName};
 }
@@ -86,29 +86,29 @@ Net::SSLLabs::Endpoint - Endpoint object
 
 =head2 new
 
-a new I<Net::SSLLabs::Endpoint> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::Endpoint> object, accepts a JSON object as it's parameter.
 
 =head2 subject
 
 certificate subject
 
-=head2 ipAddress
+=head2 ip_address
 
 endpoint IP address, in IPv4 or IPv6 format.
 
-=head2 serverName
+=head2 server_name
 
 server name retrieved via reverse DNS
 
-=head2 statusMessage
+=head2 status_message
 
 assessment status message
 
-=head2 statusDetails
+=head2 status_details
 
 code of the operation currently in progress
 
-=head2 statusDetailsMessage
+=head2 status_details_message
 
 description of the operation currently in progress
 
@@ -116,15 +116,15 @@ description of the operation currently in progress
 
 possible values: A+, A-, A-F, T (no trust) and M (certificate name mismatch)
 
-=head2 gradeTrustIgnored
+=head2 grade_trust_ignored
 
 grade (as above), if trust issues are ignored
 
-=head2 hasWarnings
+=head2 has_warnings
 
 if this endpoint has warnings that might affect the score (e.g., get A- instead of A).
 
-=head2 isExceptional
+=head2 is_exceptional
 
 this flag will be raised when an exceptional configuration is encountered. The SSL Labs test will give such sites an A+.
 
