@@ -21,7 +21,7 @@ sub status {
     return $self->{status};
 }
 
-sub statusMessage {
+sub status_message {
     my ($self) = @_;
     return $self->{statusMessage};
 }
@@ -41,22 +41,22 @@ sub port {
     return $self->{port};
 }
 
-sub startTime {
+sub start_time {
     my ($self) = @_;
     return $self->{startTime};
 }
 
-sub criteriaVersion {
+sub criteria_version {
     my ($self) = @_;
     return $self->{criteriaVersion};
 }
 
-sub engineVersion {
+sub engine_version {
     my ($self) = @_;
     return $self->{engineVersion};
 }
 
-sub isPublic {
+sub is_public {
     my ($self) = @_;
     return $self->{isPublic} ? 1 : 0;
 }
@@ -66,7 +66,7 @@ sub protocol {
     return $self->{protocol};
 }
 
-sub testTime {
+sub test_time {
     my ($self) = @_;
     return $self->{testTime};
 }
@@ -82,7 +82,7 @@ Net::SSLLabs::Host - Host object
 
 =head2 new
 
-a new I<Net::SSLLabs::Host> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::Host> object, accepts a JSON object as it's parameter.
 
 =head2 host 
 
@@ -96,7 +96,7 @@ assessment port (e.g., 443)
 
 protocol (e.g., HTTP)
 
-=head2 isPublic
+=head2 is_public
 
 true if this assessment publicly available (listed on the SSL Labs assessment boards)
 
@@ -104,27 +104,27 @@ true if this assessment publicly available (listed on the SSL Labs assessment bo
 
 assessment status; possible values: DNS, ERROR, IN_PROGRESS, and READY.
 
-=head2 statusMessage
+=head2 status_message
 
 status message in English. When status is ERROR, this field will contain an error message.
 
-=head2 startTime
+=head2 start_time
 
 assessment starting time, in milliseconds since 1970
 
-=head2 testTime
+=head2 test_time
 
 assessment completion time, in milliseconds since 1970
 
-=head2 engineVersion
+=head2 engine_version
 
 assessment engine version (e.g., "1.0.120")
 
-=head2 criteriaVersion
+=head2 criteria_version
 
 grading criteria version (e.g., "2009")
 
-=head2 cacheExpiryTime
+=head2 cache_expiry_time
 
 when will the assessment results expire from the cache (typically set only for assessment with errors; otherwise the results stay in the cache for as long as there's sufficient room)
 
@@ -132,6 +132,6 @@ when will the assessment results expire from the cache (typically set only for a
 
 list of <Net::SSLLabs::Endpoint> objects
 
-=head2 certHostnames
+=head2 cert_hostnames
 
 the list of certificate hostnames collected from the certificates seen during assessment. The hostnames may not be valid. This field is available only if the server certificate doesn't match the requested hostname. In that case, this field saves you some time as you don't have to inspect the certificates yourself to find out what valid hostnames might be.
