@@ -15,7 +15,7 @@ sub version {
     return $self->{version};
 }
 
-sub currentAssessments {
+sub current_assessments {
     my ($self) = @_;
     return $self->{currentAssessments};
 }
@@ -25,12 +25,12 @@ sub messages {
     return @{ $self->{messages} };
 }
 
-sub maxAssessments {
+sub max_assessments {
     my ($self) = @_;
     return $self->{maxAssessments};
 }
 
-sub criteriaVersion {
+sub criteria_version {
     my ($self) = @_;
     return $self->{criteriaVersion};
 }
@@ -46,25 +46,25 @@ Net::SSLLabs::Info - Info object
 
 =head2 new
 
-a new I<Net::SSLLabs::Info> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::Info> object, accepts a JSON object as it's parameter.
 
 =head2 version
 
 SSL Labs software version as a string (e.g., "1.11.14")
 
-=head2 criteriaVersion
+=head2 criteria_version
 
 rating criteria version as a string (e.g., "2009f")
 
-=head2 maxAssessments
+=head2 max_assessments
 
 the maximum number of concurrent assessments the client is allowed to initiate.
 
-=head2 currentAssessments
+=head2 current_assessments
 
 the number of ongoing assessments submitted by this client.
 
-=head2 newAssessmentCoolOff
+=head2 new_assessment_cool_off
 
 the cool-off period after each new assessment; you're not allowed to submit a new assessment before the cool-off expires, otherwise you'll get a 429.
 
