@@ -15,7 +15,7 @@ sub strength {
     return $self->{strength};
 }
 
-sub debianFlaw {
+sub debian_flaw {
     my ($self) = @_;
     return $self->{debianFlaw} ? 1 : 0;
 }
@@ -46,7 +46,7 @@ Net::SSLLabs::Key - Key object
 
 =head2 new
 
-a new I<Net::SSLLabs::Key> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::Key> object, accepts a JSON object as it's parameter.
 
 =head2 size
 
@@ -60,7 +60,7 @@ key size expressed in RSA bits.
 
 key algorithm; possible values: RSA, DSA, and EC.
 
-=head2 debianFlaw
+=head2 debian_flaw
 
 true if we suspect that the key was generated using a weak random number generator (detected via a blacklist database)
 
