@@ -25,7 +25,7 @@ sub version {
     return $self->{version};
 }
 
-sub v2SuitesDisabled {
+sub v2_suites_disabled {
     my ($self) = @_;
     return $self->{v2SuitesDisabled};
 }
@@ -46,7 +46,7 @@ Net::SSLLabs::Protocol - Protocol object
 
 =head2 new
 
-a new I<Net::SSLLabs::Protocol> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::Protocol> object, accepts a JSON object as it's parameter.
 
 =head2 id
 
@@ -60,7 +60,7 @@ protocol name, i.e. SSL or TLS.
 
 protocol version, e.g. 1.2 (for TLS)
 
-=head2 v2SuitesDisabled
+=head2 v2_suites_disabled
 
 some servers have SSLv2 protocol enabled, but with all SSLv2 cipher suites disabled. In that case, this field is set to true.
 
