@@ -30,7 +30,7 @@ sub version {
     return $self->{version};
 }
 
-sub isReference {
+sub is_reference {
     my ($self) = @_;
     return $self->{isReference} ? 1 : 0;
 }
@@ -46,7 +46,7 @@ Net::SSLLabs::SimClient - SimClient object
 
 =head2 new
 
-a new I<Net::SSLLabs::SimClient> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::SimClient> object, accepts a JSON object as it's parameter.
 
 =head2 id
 
@@ -64,6 +64,6 @@ text.
 
 text.
 
-=head2 isReference
+=head2 is_reference
 
 true if the browser is considered representative of modern browsers, false otherwise. This flag does not correlate to client's capabilities, but is used by SSL Labs to determine if a particular configuration is effective. For example, to track Forward Secrecy support, we mark several representative browsers as "modern" and then test to see if they succeed in negotiating a FS suite. Just as an illustration, modern browsers are currently Chrome, Firefox (not ESR versions), IE/Win7, and Safari.
