@@ -17,7 +17,7 @@ sub client {
     return $self->{client};
 }
 
-sub errorCode {
+sub error_code {
     my ($self) = @_;
     return $self->{errorCode};
 }
@@ -27,12 +27,12 @@ sub attempts {
     return $self->{attempts};
 }
 
-sub protocolId {
+sub protocol_id {
     my ($self) = @_;
     return $self->{protocolId};
 }
 
-sub suiteId {
+sub suite_id {
     my ($self) = @_;
     return $self->{suiteId};
 }
@@ -48,13 +48,13 @@ Net::SSLLabs::Simulation - Simulation object
 
 =head2 new
 
-a new I<Net::SSLLabs::Simulation> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::Simulation> object, accepts a JSON object as it's parameter.
 
 =head2 client
 
 instance of L<Net::SSLLabs::SimClient|Net::SSLLabs::SimClient>.
 
-=head2 errorCode
+=head2 error_code
 
 zero if handshake was successful, 1 if it was not.
 
@@ -62,11 +62,11 @@ zero if handshake was successful, 1 if it was not.
 
 always 1 with the current implementation.
 
-=head2 protocolId
+=head2 protocol_id
 
 Negotiated protocol ID.
 
-=head2 suiteId
+=head2 suite_id
 
 Negotiated suite ID.
 
