@@ -10,7 +10,7 @@ sub new {
     return $self;
 }
 
-sub statusDetails {
+sub status_details {
     my ($self) = @_;
     return %{ $self->{statusDetails} };
 }
@@ -26,8 +26,8 @@ Net::SSLLabs::StatusCodes - StatusCodes object
 
 =head2 new
 
-a new I<Net::SSLLabs::StatusCodes> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::StatusCodes> object, accepts a JSON object as it's parameter.
 
-=head2 statusDetails
+=head2 status_details
 
 a hash containing all status details codes and the corresponding English translations. Please note that, once in use, the codes will not change, whereas the translations may change at any time.
