@@ -11,7 +11,7 @@ sub new {
     return $self;
 }
 
-sub cipherStrength {
+sub cipher_strength {
     my ($self) = @_;
     return $self->{cipherStrength};
 }
@@ -21,32 +21,32 @@ sub name {
     return $self->{name};
 }
 
-sub ecdhBits {
+sub ecdh_bits {
     my ($self) = @_;
     return $self->{ecdhBits};
 }
 
-sub ecdhStrength {
+sub ecdh_strength {
     my ($self) = @_;
     return $self->{ecdhStrength};
 }
 
-sub dhStrength {
+sub dh_strength {
     my ($self) = @_;
     return $self->{dhStrength};
 }
 
-sub dhYs {
+sub dh_ys {
     my ($self) = @_;
     return $self->{dhYs};
 }
 
-sub dhG {
+sub dh_g {
     my ($self) = @_;
     return $self->{dhG};
 }
 
-sub dhP {
+sub dh_p {
     my ($self) = @_;
     return $self->{dhP};
 }
@@ -67,7 +67,7 @@ Net::SSLLabs::Suite - Suite object
 
 =head2 new
 
-a new I<Net::SSLLabs::Suite> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::Suite> object, accepts a JSON object as it's parameter.
 
 =head2 id
 
@@ -77,31 +77,31 @@ suite RFC ID (e.g., 5)
 
 suite name (e.g., TLS_RSA_WITH_RC4_128_SHA)
 
-=head2 cipherStrength
+=head2 cipher_strength
 
 suite strength (e.g., 128)
 
-=head2 dhStrength
+=head2 dh_strength
 
 strength of DH params (e.g., 1024)
 
-=head2 dhP
+=head2 dh_p
 
 DH params, p component
 
-=head2 dhG
+=head2 dh_g
 
 DH params, g component
 
-=head2 dhYs
+=head2 dh_ys
 
 DH params, Ys component
 
-=head2 ecdhBits
+=head2 ecdh_bits
 
 ECDH bits
 
-=head2 ecdhStrength
+=head2 ecdh_strength
 
 ECDH RSA-equivalent strength
 
